if __name__ == "__main__":
  # Third party imports
  from aeth_ext import initialize

  initialize()
# else:
#   from rich import get_console

#   RICH_CONSOLE = get_console()

# Standard library imports
from logging import getLogger

# Third party imports
from pandas import DataFrame, read_csv

# First party imports
from timeclock_entry_processor.environment_init_vars import CWD

logger = getLogger(__name__)

EMPLOYEE_INPUT_DIR = CWD / "employee_input"
EMPLOYEE_INPUT_DIR.mkdir(exist_ok=True)  # Ensure the directory exists

MANUAL_EMPLOYEE_LIST_CSV = max(EMPLOYEE_INPUT_DIR.iterdir(), key=lambda f: f.stat().st_mtime)

type EmployeeGroup = str
type EmployeeName = str


def get_employee_info() -> DataFrame:  # sourcery skip: extract-method
  employee_df = read_csv(
    MANUAL_EMPLOYEE_LIST_CSV,
    header=0,
    names=[
      "id",
      "First Name",
      "Last Name",
      "Status",
      "Manager",
      "Hire Date",
      "group",
      "Work Type",
      "Notes",
      "Created",
      "Updated",
    ],
    usecols=["id", "First Name", "Last Name", "group"],
    dtype=str,
  )
  employee_df["name"] = employee_df["First Name"].str.strip() + " " + employee_df["Last Name"].str.strip()
  employee_df = employee_df[["id", "name", "group"]]

  return employee_df


if __name__ == "__main__":
  get_employee_info()



if __name__ == "__main__":
  # Standard library imports
  from os import environ
  from sys import platform

  # Third party imports
  from aeth_ext import initialize
  from rich.console import Console

  environ["TYPER_USE_RICH "] = "0"

  RICH_CONSOLE = Console(
    width=None if platform == "win32" else 165,
    log_time=platform == "win32",
  )
  PROJECT_NAME = "timeclock_entry_processor"
  LOGGING_TYPE = "daily"

  # Standard library imports
  from multiprocessing import Queue

  mp_queue = Queue()

  initialize(mp_queue)


# Standard library imports
from pathlib import Path  # noqa: TC003
from typing import Annotated

# Third party imports
import typer

# First party imports
from timeclock_entry_processor import main
from timeclock_entry_processor.environment_init_vars import CWD


def cli(
  csv_file: Path,
  manifest_file: Annotated[Path | None, typer.Argument()] = None,
  output_folder: Annotated[Path, typer.Argument()] = CWD / "timeclock_entry_processor_output",
):
  if not csv_file.exists():
    RICH_CONSOLE.print(f"[red]Error: File '{csv_file}' does not exist.[/red]")
    raise typer.Exit(code=1)
  output_folder.mkdir(parents=True, exist_ok=True)

  main(mp_queue, csv_file, output_folder, manifest_file)


if __name__ == "__main__":
  # cli(Path.cwd() / "input" / "Time-Clock-Entry-Report_2026-05-08_17-53-58.csv", manifest_file=Path.cwd() / "manifest.json")
  typer.run(cli)
